#!/bin/env python

import os
import sys
import time
import SWOTftputils

################################################################################
# Main program for getSWOTData.py
################################################################################
"""
    Program for downloading SWOT data products from PO.DAAC cloud

    To use this program you need to (1) create netrc file to access the machine
    and (2) create a token to gain access to the data, see below:

    Installation procedure:
    
    1. create .netrc file on your system
    2. add the following to .netrc
        machine urs.earthdata.nasa.gov login <your Earthdata username> password <your Earth data password>
    3. run following command:
        chmod 0600 ~/.netrc

    You should now be able to use this script!

    *** Example ***

    # To get help on options available to script
    python3 getSWOTData.py -h

    # To get listing of PODAAC datasets that are currently coded into this software
    python3 getSWOTData.py -pdesc

    # The get listing of SMM_ICN and ICS files available at PODAAC over last 1000000 minutes
    python3 getSWOTData.py -p SMM_ICN_ICS -w 1000000 -listonly

    # To pull all SMM_ICN and ICS files available at PODAAC over last 1000000 minutes
    python3 getSWOTData.py -p SMM_ICN_ICS -w 1000000 -s 0

    # To pull all SMM_ICN and ICS files available at PODAAC over last 1000000 minutes
    python3 getSWOTData.py -p SMM_ICN_ICS -w 1000000 -s 0

    # To only pull SMM_ICN files available at PODAAC over last 1000000 minutes
    python3 getSWOTData.py -p SMM_ICN_ICS -w 1000000 -s 0 -f ICN

    # To only pull SMM_ICN and SMM_ICS files available at PODAAC over last 1000000 minutes for granule with patter AXVCNE20160928
    python3 getSWOTData.py -p SMM_ICN_ICS -w 1000000 -s 0 -f AXVCNE20160928 
        
        
    *** Notes and updates ***

    * In SWOTftputils.py you might need to change CMR and MACHINE to new addresses
    for the operational enviroment.

    * In exts and patterns in the getSWOTdata function you can select wanted file
    endings and also match string patterns in the filename. 
    
    * Added logfile as parser object for SWOTftutils.py, so it can be provided
    without changing the main program 

"""
     
if __name__ == "__main__":
     
    # Read input arguments
    args = SWOTftputils.parseArgs()

    # Get parameters
    tspan    = args.twin
    ccid     = args.prodid
    ddir     = args.ddir
    token    = args.token
    sleep    = args.sleep
    extlist  = args.extlist
    pattlist = args.pattlist
    logfile  = args.logfile
    search_cycles = args.search_cycles
    search_pass = args.search_pass
    sleep   *= 60
    pdesc    = args.prodiddesc
    listonly = args.listonly
   
    while True:
        
        if logfile is None:
            log_file = sys.__stdout__
        elif os.path.exists(logfile):
            log_file = open(logfile,"a")
        else:
            log_file = open(logfile,"w")

        f_fail, f_ok, time_last = SWOTftputils.getSWOTdata(ccid, ddir, token, log_file, \
                                  tspan, search_cycles, search_pass, exts=extlist, patterns=pattlist, pdesc=pdesc,
                                  listonly=listonly)
        log_file.close()
    
        if sleep != 0:
            time.sleep(sleep)
        else:
            break
